==> client-java-api-fluent-15.0.2-sources.jar: io/kubernetes/client/openapi/models/V1IngressBuilder.java <==
/*
Copyright 2022 The Kubernetes Authors.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;

public class V1IngressBuilder extends V1IngressFluentImpl<V1IngressBuilder>
    implements VisitableBuilder<V1Ingress, io.kubernetes.client.openapi.models.V1IngressBuilder> {
  public V1IngressBuilder() {
    this(false);
  }

  public V1IngressBuilder(Boolean validationEnabled) {
    this(new V1Ingress(), validationEnabled);
  }

  public V1IngressBuilder(io.kubernetes.client.openapi.models.V1IngressFluent<?> fluent) {
    this(fluent, false);
  }

  public V1IngressBuilder(
      io.kubernetes.client.openapi.models.V1IngressFluent<?> fluent,
      java.lang.Boolean validationEnabled) {
    this(fluent, new V1Ingress(), validationEnabled);
  }

  public V1IngressBuilder(
      io.kubernetes.client.openapi.models.V1IngressFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1Ingress instance) {
    this(fluent, instance, false);
  }

  public V1IngressBuilder(
      io.kubernetes.client.openapi.models.V1IngressFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1Ingress instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = fluent;
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    fluent.withSpec(instance.getSpec());

    fluent.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled;
  }

  public V1IngressBuilder(io.kubernetes.client.openapi.models.V1Ingress instance) {
    this(instance, false);
  }

  public V1IngressBuilder(
      io.kubernetes.client.openapi.models.V1Ingress instance, java.lang.Boolean validationEnabled) {
    this.fluent = this;
    this.withApiVersion(instance.getApiVersion());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.withSpec(instance.getSpec());

    this.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled;
  }

  io.kubernetes.client.openapi.models.V1IngressFluent<?> fluent;
  java.lang.Boolean validationEnabled;

  public io.kubernetes.client.openapi.models.V1Ingress build() {
    V1Ingress buildable = new V1Ingress();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    buildable.setSpec(fluent.getSpec());
    buildable.setStatus(fluent.getStatus());
    return buildable;
  }
}

==> client-java-api-fluent-18.0.1-sources.jar: io/kubernetes/client/openapi/models/V1IngressBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Boolean;
public class V1IngressBuilder extends V1IngressFluentImpl<V1IngressBuilder> implements VisitableBuilder<V1Ingress,V1IngressBuilder>{
  public V1IngressBuilder() {
    this(false);
  }
  public V1IngressBuilder(Boolean validationEnabled) {
    this(new V1Ingress(), validationEnabled);
  }
  public V1IngressBuilder(V1IngressFluent<?> fluent) {
    this(fluent, false);
  }
  public V1IngressBuilder(V1IngressFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new V1Ingress(), validationEnabled);
  }
  public V1IngressBuilder(V1IngressFluent<?> fluent,V1Ingress instance) {
    this(fluent, instance, false);
  }
  public V1IngressBuilder(V1IngressFluent<?> fluent,V1Ingress instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    fluent.withSpec(instance.getSpec());

    fluent.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled; 
  }
  public V1IngressBuilder(V1Ingress instance) {
    this(instance,false);
  }
  public V1IngressBuilder(V1Ingress instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.withSpec(instance.getSpec());

    this.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled; 
  }
  V1IngressFluent<?> fluent;
  Boolean validationEnabled;
  public V1Ingress build() {
    V1Ingress buildable = new V1Ingress();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    buildable.setSpec(fluent.getSpec());
    buildable.setStatus(fluent.getStatus());
    return buildable;
  }
  
}
